@@ -37,36 +37,21 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
   };
 
   pub.setEnigmailPrefs = function(anonService) {
+    var opts = "";
     if (pub.prefs.getBoolPref("extensions.torbirdy.enigmail.throwkeyid")) {
-      if (anonService === "tor") {
-        return "--no-emit-version " +
-               "--no-comments " +
-               "--throw-keyids " +
-               "--display-charset utf-8 " +
-               "--keyserver-options no-auto-key-retrieve,no-try-dns-srv,http-proxy=http://127.0.0.1:8118";
-      }
-      if (anonService === "jondo") {
-        return "--no-emit-version " +
-               "--no-comments " +
-               "--throw-keyids " +
-               "--display-charset utf-8 " +
-               "--keyserver-options no-auto-key-retrieve,no-try-dns-srv,http-proxy=http://127.0.0.1:4001";
-      }
+      opts += "--throw-keyids ";
     }
-    else {
-      if (anonService === "tor") {
-        return "--no-emit-version " +
-               "--no-comments " +
-               "--display-charset utf-8 " +
-               "--keyserver-options no-auto-key-retrieve,no-try-dns-srv,http-proxy=http://127.0.0.1:8118";
-      }
-      if (anonService === "jondo") {
-        return "--no-emit-version " +
-               "--no-comments " +
-               "--display-charset utf-8 " +
-               "--keyserver-options no-auto-key-retrieve,no-try-dns-srv,http-proxy=http://127.0.0.1:4001";
-      }
+    var proxy = "socks5h://127.0.0.1:9150";
+    if (anonService === "jondo") {
+      proxy = "http://127.0.0.1:4001";
     }
+
+    return opts +
+           "--no-emit-version " +
+           "--no-comments " +
+           "--display-charset utf-8 " +
+           "--keyserver-options no-auto-key-retrieve,no-try-dns-srv,http-proxy=" +
+           proxy;
   };
 
   pub.updateKeyserver = function(anonService) {
@@ -92,7 +77,7 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
 
   pub.clearCustomPrefs = function() {
     var customPrefs = pub.torBirdyPref.getChildList("", {});
-    for (var i = 0; i < customPrefs.length; i++) {
+    for (let i = 0; i < customPrefs.length; i++) {
       pub.prefs.clearUserPref(pub.customBranch + customPrefs[i]);
     }
   };
@@ -144,15 +129,10 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
     var mailAccounts = [];
     var accounts = pub.acctMgr.accounts;
 
-    // To maintain compatibility between Gecko 17+ and Gecko < 17.
-    var newGecko = (accounts.queryElementAt) ? true : false;
+    var accountLength = accounts.length;
 
-    var accountLength = newGecko ? accounts.length : accounts.Count();
-
-    for (var i = 0; i < accountLength; i++) {
-      var account = (newGecko) ?
-                    accounts.queryElementAt(i, Components.interfaces.nsIMsgAccount).incomingServer :
-                    accounts.QueryElementAt(i, Components.interfaces.nsIMsgAccount).incomingServer;
+    for (let i = 0; i < accountLength; i++) {
+      var account = accounts.queryElementAt(i, Components.interfaces.nsIMsgAccount).incomingServer;
 
       var name = account.prettyName;
       if (!(name === "Local Folders")) {
@@ -169,7 +149,7 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
       // For email accounts, configure accordingly.
       var sAccount = null;
       var account = pub.getAccount();
-      for (var i = 0; i < account.length; i++) {
+      for (let i = 0; i < account.length; i++) {
         if (account[i].key === pub.mailAccount.value) {
           sAccount = i;
         }
@@ -337,30 +317,6 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
       pub.prefs.setBoolPref(pub.prefBranch + 'startup_folder', false);
     }
 
-    // Time zone.
-    // default: true
-    var timezone = pub.timezone.checked;
-    // Only update pub if required.
-    if (timezone === pub.prefs.getBoolPref(pub.prefBranch + 'timezone')) {
-        var env = Components.classes["@mozilla.org/process/environment;1"]
-                                      .getService(Components.interfaces.nsIEnvironment);
-        if (timezone) {
-          pub.prefs.setBoolPref(pub.prefBranch + 'timezone', false);
-          env.set('TZ', '');
-        } else {
-          pub.prefs.setBoolPref(pub.prefBranch + 'timezone', true);
-          env.set('TZ', 'UTC');
-        }
-
-        // Ask the user to restart Thunderbird. We can't do pub for the user
-        // because the environment variables are not reset without quitting
-        // Thunderbird and starting it again.
-        var prompts = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
-                                        .getService(Components.interfaces.nsIPromptService);
-        prompts.alert(null, pub.strBundle.GetStringFromName("torbirdy.name"),
-                            pub.strBundle.GetStringFromName("torbirdy.restart"));
-    }
-
     // Fetch all messages for all accounts.
     // default: false
     // Only change the state if it is required.
@@ -368,14 +324,14 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
       var accounts = pub.getAccount();
       if (pub.fetchAllMails.checked) {
         pub.prefs.setBoolPref(pub.prefBranch + 'fetchall', true);
-        for (var i = 0; i < accounts.length; i++) {
+        for (let i = 0; i < accounts.length; i++) {
           accounts[i].loginAtStartUp = true;
           accounts[i].doBiff = true;
         }
       }
       else {
         pub.prefs.setBoolPref(pub.prefBranch + 'fetchall', false);
-        for (var i = 0; i < accounts.length; i++) {
+        for (let i = 0; i < accounts.length; i++) {
           accounts[i].loginAtStartUp = false;
           accounts[i].doBiff = false;
         }
@@ -408,18 +364,6 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
       pub.prefs.setBoolPref(pub.prefBranch + 'emailwizard', false);
     }
 
-    // Insecure renegotiation - default: false (opt-out for mailservers that do
-    // not support secure renegotiation yet)
-    var securityRenegotiation = 'security.ssl.require_safe_negotiation';
-    var securityWarn = 'security.ssl.treat_unsafe_negotiation_as_broken';
-    if (pub.secureRenegotiation.checked) {
-      pub.setPreferences(securityRenegotiation, false);
-      pub.setPreferences(securityWarn, false);
-    } else {
-      pub.clearSinglePref(securityRenegotiation);
-      pub.clearSinglePref(securityWarn);
-    }
-
     if (index === 1) {
       // JonDo.
       if (pub.anonCustomService.selectedIndex === 0) {
@@ -451,7 +395,6 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
     pub.mailAccount = document.getElementById('torbirdy-mail-accounts');
     pub.imapIdle = document.getElementById('torbirdy-idle');
     pub.startupFolder = document.getElementById('torbirdy-startup-folder');
-    pub.timezone = document.getElementById('torbirdy-timezone');
     pub.emailWizard = document.getElementById('torbirdy-email-wizard');
     pub.fetchAllMails = document.getElementById('torbirdy-email-automatic');
     // Enigmail.
@@ -540,14 +483,6 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
       pub.startupFolder.checked = true;
     }
 
-    // Time zone settings.
-    // default: true
-    if (pub.prefs.getBoolPref(pub.prefBranch + 'timezone')) {
-      pub.timezone.checked = false;
-    } else {
-      pub.timezone.checked = true;
-    }
-
     // Fetch all messages for all accounts.
     // default: false
     if (pub.prefs.getBoolPref(pub.prefBranch + 'fetchall')) {
@@ -589,12 +524,6 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
     /*
      Security
     */
-    // Allow insecure renegotiation - default: false
-    if (pub.prefs.prefHasUserValue(pub.customBranch + 'security.ssl.require_safe_negotiation')) {
-      pub.secureRenegotiation.checked = true;
-    } else {
-      pub.secureRenegotiation.checked = false;
-    }
 
     // Load the email accounts.
     var accounts = pub.getAccount();
@@ -634,7 +563,6 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
   pub.restoreDefaults = function() {
     // Set the values to their default state.
     pub.anonService.selectedIndex = 0;
-    pub.timezone.checked = false;
     pub.enigmailKeyId.checked = false;
     pub.enigmailConfirmEmail.checked = false;
     pub.emailWizard.checked = false;
