@@ -37,8 +37,6 @@ var TorBirdyPrefs = {
 
   // Use a manual proxy configuration.
   "network.proxy.type": 1,
-  // https://bugs.torproject.org/10419
-  "network.proxy.no_proxies_on": "",
   // Restrict TBB ports.
   "network.security.ports.banned": "9050,9051,9150,9151",
   // Number of seconds to wait before attempting to recontact an unresponsive proxy server.
@@ -312,9 +310,6 @@ var TorBirdyPrefs = {
 
   // Mozilla Lightning.
   "calendar.useragent.extra": "",
-  // We have to set a timezone otherwise the system time is used. "UTC" or
-  // "GMT" is not an option so we set it to Europe/London.
-  "calendar.timezone.local": "Europe/London",
 
   /*
    Other Settings
@@ -325,6 +320,7 @@ var TorBirdyPrefs = {
   // These are similar to the mailnews.* settings.
   "rss.display.disallow_mime_handlers": 3,
   "rss.display.html_as": 1,
+  "rss.show.content-base": 1,
 
   // Override the user agent by setting it to an empty string.
   "general.useragent.override": "",
